@@ -20,29 +20,82 @@ from beartype.roar import (
     BeartypeCallHintReturnViolation,
     BeartypeDoorHintViolation,
 )
-# from beartype.roar._roarwarn import (
-#     _BeartypeConfReduceDecoratorExceptionToWarningDefault)
-from beartype.typing import Optional
 from beartype._cave._cavemap import NoneTypeOr
 from beartype._conf.confenum import (
-    BeartypeDecorationPosition,
     BeartypeStrategy,
     BeartypeViolationVerbosity,
 )
-from beartype._conf.confoverrides import (
-    beartype_hint_overrides_pep484_tower,
-    BeartypeHintOverrides,
-)
-from beartype._data.hint.datahinttyping import (
+from beartype._conf.decorplace.confplaceenum import BeartypeDecorPlace
+from beartype._conf._confoverrides import sanify_conf_kwargs_is_pep484_tower
+from beartype._data.typing.datatyping import (
     DictStrToAny,
     TypeException,
 )
 from beartype._util.cls.utilclstest import is_type_subclass
+from beartype._util.error.utilerrwarn import issue_warning
+from beartype._util.kind.maplike.utilmapfrozen import FrozenDict
 from beartype._util.text.utiltextidentifier import is_identifier
 from collections.abc import (
     Collection as CollectionABC,
 )
 
+# ....................{ DEFAULTERS                         }....................
+def default_conf_kwargs(conf_kwargs: DictStrToAny) -> None:
+    '''
+    Default all parameters not explicitly passed by the user in the passed
+    dictionary of configuration parameters to sane internal defaults *before*
+    the :func:`.die_if_conf_kwargs_invalid` raiser validates these parameters.
+
+    Parameters
+    ----------
+    conf_kwargs : Dict[str, object]
+        Dictionary mapping from the names to values of *all* possible keyword
+        parameters configuring this configuration.
+    '''
+    assert isinstance(conf_kwargs, dict), f'{repr(conf_kwargs)} not dictionary.'
+
+    # ..................{ DEFAULT ~ violation_*type          }..................
+    # Default violation type if passed *OR* "None" if unpassed.
+    violation_type = conf_kwargs['violation_type']
+
+    # If...
+    if (
+        # The caller explicitly passed a default violation type...
+        violation_type is not None and
+        # That is *NOT* an exception subclass...
+        not is_type_subclass(violation_type, Exception)
+    # Raise an exception.
+    ):
+        raise BeartypeConfParamException(
+            f'Beartype configuration parameter "violation_type" value '
+            f'{repr(violation_type)} not exception type.'
+        )
+    # Else, the caller either passed *NO* default violation type or passed a
+    # valid default violation type.
+
+    # If the caller did *NOT* explicitly pass a DOOR violation type, default
+    # this type to either the default violation type if passed *OR* the default
+    # DOOR violation type if unpassed.
+    if conf_kwargs['violation_door_type'] is None:
+        conf_kwargs['violation_door_type'] = (
+            violation_type or BeartypeDoorHintViolation)
+    # Else, the caller explicitly passed a DOOR violation type.
+
+    # If the caller did *NOT* explicitly pass a parameter violation type,
+    # default this type to either the default violation type if passed *OR* the
+    # default DOOR violation type if unpassed.
+    if conf_kwargs['violation_param_type'] is None:
+        conf_kwargs['violation_param_type'] = (
+            violation_type or BeartypeCallHintParamViolation)
+
+    # If the caller did *NOT* explicitly pass a return violation type, default
+    # this type to either the default violation type if passed *OR* the default
+    # DOOR violation type if unpassed.
+    if conf_kwargs['violation_return_type'] is None:
+        conf_kwargs['violation_return_type'] = (
+            violation_type or BeartypeCallHintReturnViolation)
+    # Else, the caller explicitly passed a DOOR violation type.
+
 # ....................{ RAISERS                            }....................
 def die_unless_conf(
     # Mandatory parameters.
@@ -69,7 +122,7 @@ def die_unless_conf(
     '''
 
     # Avoid circular import dependencies.
-    from beartype._conf.confcls import BeartypeConf
+    from beartype._conf.confmain import BeartypeConf
 
     # If this object is *NOT* a configuration, raise an exception.
     if not isinstance(conf, BeartypeConf):
@@ -101,31 +154,31 @@ def die_if_conf_kwargs_invalid(conf_kwargs: DictStrToAny) -> None:
     '''
 
     # ..................{ VALIDATE                           }..................
-    # If "claw_decoration_position_funcs" is *NOT* an enumeration member, raise
+    # If "claw_decor_place_func" is *NOT* an enumeration member, raise
     # an exception.
     if not isinstance(
-        conf_kwargs['claw_decoration_position_funcs'],
-        BeartypeDecorationPosition
+        conf_kwargs['claw_decor_place_func'],
+        BeartypeDecorPlace
     ):
         raise BeartypeConfParamException(
-            f'Beartype configuration parameter "claw_decoration_position_funcs" '
-            f'value {repr(conf_kwargs["claw_decoration_position_funcs"])} not '
-            f'"beartype.BeartypeDecorationPosition" enumeration member.'
+            f'Beartype configuration parameter "claw_decor_place_func" '
+            f'value {repr(conf_kwargs["claw_decor_place_func"])} not '
+            f'"beartype.BeartypeDecorPlace" enumeration member.'
         )
-    # Else, "claw_decoration_position_funcs" is an enumeration member.
+    # Else, "claw_decor_place_func" is an enumeration member.
     #
-    # If "claw_decoration_position_types" is *NOT* an enumeration member, raise
+    # If "claw_decor_place_type" is *NOT* an enumeration member, raise
     # an exception.
     elif not isinstance(
-        conf_kwargs['claw_decoration_position_types'],
-        BeartypeDecorationPosition
+        conf_kwargs['claw_decor_place_type'],
+        BeartypeDecorPlace
     ):
         raise BeartypeConfParamException(
-            f'Beartype configuration parameter "claw_decoration_position_types" '
-            f'value {repr(conf_kwargs["claw_decoration_position_types"])} not '
-            f'"beartype.BeartypeDecorationPosition" enumeration member.'
+            f'Beartype configuration parameter "claw_decor_place_type" '
+            f'value {repr(conf_kwargs["claw_decor_place_type"])} not '
+            f'"beartype.BeartypeDecorPlace" enumeration member.'
         )
-    # Else, "claw_decoration_position_types" is an enumeration member.
+    # Else, "claw_decor_place_type" is an enumeration member.
     #
     # If "claw_is_pep526" is *NOT* a boolean, raise an exception.
     elif not isinstance(conf_kwargs['claw_is_pep526'], bool):
@@ -154,27 +207,27 @@ def die_if_conf_kwargs_invalid(conf_kwargs: DictStrToAny) -> None:
         raise BeartypeConfParamException(
             f'Beartype configuration parameter "claw_skip_package_names" '
             f'value {repr(conf_kwargs["claw_skip_package_names"])} not '
-            f'collection of non-empty strings.'
+            f'collection of "."-delimited Python identifiers.'
         )
     # Else, "claw_skip_package_names" is an iterable of non-empty strings.
     #
     # If "hint_overrides" is *NOT* a frozen dict, raise an exception.
-    elif not isinstance(conf_kwargs['hint_overrides'], BeartypeHintOverrides):
+    elif not isinstance(conf_kwargs['hint_overrides'], FrozenDict):
         raise BeartypeConfParamException(
             f'Beartype configuration parameter "hint_overrides" '
             f'value {repr(conf_kwargs["hint_overrides"])} not '
             f'frozen dictionary '
-            f'(i.e., "beartype.BeartypeHintOverrides" instance).'
+            f'(i.e., "beartype.FrozenDict" instance).'
         )
     # Else, "hint_overrides" is a frozen dict.
     #
-    # If "is_check_pep557" is *NOT* a boolean, raise an exception.
-    elif not isinstance(conf_kwargs['is_check_pep557'], bool):
+    # If "is_pep557_fields" is *NOT* a boolean, raise an exception.
+    elif not isinstance(conf_kwargs['is_pep557_fields'], bool):
         raise BeartypeConfParamException(
-            f'Beartype configuration parameter "is_check_pep557" '
-            f'value {repr(conf_kwargs["is_check_pep557"])} not boolean.'
+            f'Beartype configuration parameter "is_pep557_fields" '
+            f'value {repr(conf_kwargs["is_pep557_fields"])} not boolean.'
         )
-    # Else, "is_check_pep557" is a boolean.
+    # Else, "is_pep557_fields" is a boolean.
     #
     # If "is_color" is *NOT* a tri-state boolean, raise an exception.
     elif not isinstance(conf_kwargs['is_color'], NoneTypeOr[bool]):
@@ -252,69 +305,41 @@ def die_if_conf_kwargs_invalid(conf_kwargs: DictStrToAny) -> None:
                 f'exception type.'
             )
 
-# ....................{ DEFAULTERS                         }....................
-def default_conf_kwargs_before(conf_kwargs: DictStrToAny) -> None:
+# ....................{ DEPRECATORS                        }....................
+def issue_warning_deprecated_option(
+    option_name_old: str, option_name_new: str) -> None:
     '''
-    Sanitize the passed dictionary of configuration parameters by defaulting all
-    parameters not explicitly passed by the user to sane internal defaults
-    *before* the :func:`.die_if_conf_kwargs_invalid` raiser validates these
-    parameters.
+    Issue a non-fatal deprecation warning advising the caller that the parameter
+    with the passed "old" name has been deprecated in favour of the parameter
+    with the passed "new" name.
 
     Parameters
     ----------
-    conf_kwargs : Dict[str, object]
-        Dictionary mapping from the names to values of *all* possible keyword
-        parameters configuring this configuration.
+    option_name_old : str
+        Name of the deprecated "old" configuration option passed by the caller.
+    option_name_new : str
+        Name of the corresponding non-deprecated "new" configuration option
+        *not* passed by the caller.
     '''
-    assert isinstance(conf_kwargs, dict), f'{repr(conf_kwargs)} not dictionary.'
+    assert isinstance(option_name_old, str)
+    assert isinstance(option_name_new, str)
 
-    # ..................{ DEFAULT ~ violation_*type          }..................
-    # Default violation type if passed *OR* "None" if unpassed.
-    violation_type = conf_kwargs['violation_type']
+    # Issue this non-fatal deprecation warning.
+    issue_warning(
+        cls=DeprecationWarning,
+        message=(
+            f'Beartype configuration option "{option_name_old}" '
+            f'deprecated by new option "{option_name_new}", '
+            f'because beartype is here to annoy you when you were '
+            f'just about to go home.\n'
+            f'tl;dr: pass "{option_name_new}" instead, please. *sigh*'
+        ),
+    )
 
-    # If...
-    if (
-        # The caller explicitly passed a default violation type...
-        violation_type is not None and
-        # That is *NOT* an exception subclass...
-        not is_type_subclass(violation_type, Exception)
-    # Raise an exception.
-    ):
-        raise BeartypeConfParamException(
-            f'Beartype configuration parameter "violation_type" value '
-            f'{repr(violation_type)} not exception type.'
-        )
-    # Else, the caller either passed *NO* default violation type or passed a
-    # valid default violation type.
-
-    # If the caller did *NOT* explicitly pass a DOOR violation type, default
-    # this type to either the default violation type if passed *OR* the default
-    # DOOR violation type if unpassed.
-    if conf_kwargs['violation_door_type'] is None:
-        conf_kwargs['violation_door_type'] = (
-            violation_type or BeartypeDoorHintViolation)
-    # Else, the caller explicitly passed a DOOR violation type.
-
-    # If the caller did *NOT* explicitly pass a parameter violation type,
-    # default this type to either the default violation type if passed *OR* the
-    # default DOOR violation type if unpassed.
-    if conf_kwargs['violation_param_type'] is None:
-        conf_kwargs['violation_param_type'] = (
-            violation_type or BeartypeCallHintParamViolation)
-
-    # If the caller did *NOT* explicitly pass a return violation type, default
-    # this type to either the default violation type if passed *OR* the default
-    # DOOR violation type if unpassed.
-    if conf_kwargs['violation_return_type'] is None:
-        conf_kwargs['violation_return_type'] = (
-            violation_type or BeartypeCallHintReturnViolation)
-    # Else, the caller explicitly passed a DOOR violation type.
-
-
-def default_conf_kwargs_after(conf_kwargs: DictStrToAny) -> None:
+# ....................{ SANIFIERS                          }....................
+def sanify_conf_kwargs(conf_kwargs: DictStrToAny) -> None:
     '''
-    Sanitize the passed dictionary of configuration parameters by defaulting all
-    parameters not explicitly passed by the user to sane internal defaults
+    Sanify (i.e., sanitize) the passed dictionary of configuration parameters
     *after* the :func:`.die_if_conf_kwargs_invalid` raiser validates these
     parameters.
 
@@ -327,63 +352,10 @@ def default_conf_kwargs_after(conf_kwargs: DictStrToAny) -> None:
     assert isinstance(conf_kwargs, dict), f'{repr(conf_kwargs)} not dictionary.'
 
     # ..................{ DEFAULT ~ hint_overrides           }..................
-    # If enabling the PEP 484-compliant implicit numeric tower...
+    # If enabling the PEP 484-compliant implicit numeric tower, dynamically
+    # synthesize this tower from this existing configuration.
     if conf_kwargs['is_pep484_tower']:
-        # PEP 484-compliant implicit tower type hint overrides (i.e.,
-        # "BeartypeHintOverrides" instance lossily convering integers to
-        # floating-point numbers *AND* both integers and floating-point numbers
-        # to complex numbers).
-        BEARTYPE_HINT_OVERRIDES_PEP484_TOWER = (
-            beartype_hint_overrides_pep484_tower())
-
-        # Hint overrides if passed by the caller *OR* "None" otherwise.
-        hint_overrides = conf_kwargs['hint_overrides']
-
-        # Target hint overrides for the source "float" and "complex" types if
-        # any *OR* "None" otherwise.
-        hint_overrides_float = hint_overrides.get(float)
-        hint_overrides_complex = hint_overrides.get(complex)
-
-        # Whichever of the "float" or "complex" types are already existing
-        # overrides in the passed type hint overrides.
-        hint_override_cls_conflict: Optional[type] = None
-
-        # If these overrides already define conflicting overrides for either the
-        # "float" or "complex" types, record that fact.
-        if (
-            hint_overrides_float and
-            hint_overrides_float != BEARTYPE_HINT_OVERRIDES_PEP484_TOWER[float]
-        ):
-            hint_override_cls_conflict = float
-        elif (
-            hint_overrides_complex and
-            hint_overrides_complex != BEARTYPE_HINT_OVERRIDES_PEP484_TOWER[
-                complex]
-        ):
-            hint_override_cls_conflict = complex
-        # Else, these overrides do *NOT* already define conflicting overrides
-        # for either the "float" or "complex" types.
-
-        # If these overrides already define conflicting overrides for either the
-        # "float" or "complex" types, raise an exception.
-        if hint_override_cls_conflict:
-            raise BeartypeConfParamException(
-                f'Beartype configuration '
-                f'parameter "is_pep484_tower" conflicts with '
-                f'parameter "hint_overrides" key '
-                f'"{hint_override_cls_conflict.__name__}" '
-                f'value '
-                f'{repr(hint_overrides[hint_override_cls_conflict])}.'
-            )
-        # Else, these overrides do *NOT* already define conflicting overrides
-        # for either the "float" or "complex" types.
-
-        # Add hint overrides expanding the passed type hint overrides with
-        # additional overrides mapping:
-        # * The "float" type to the "float | int" type hint.
-        # * The "complex" type to the "complex | float | int" type hint.
-        conf_kwargs['hint_overrides'] = (
-            hint_overrides | BEARTYPE_HINT_OVERRIDES_PEP484_TOWER)  # type: ignore[assignment]
+        sanify_conf_kwargs_is_pep484_tower(conf_kwargs)
     # Else, the PEP 484-compliant implicit numeric tower is disabled.
 
 # ....................{ PRIVATE ~ globals                  }....................
