@@ -19,14 +19,18 @@ from beartype.typing import (
     Union,
 )
 from beartype._cave._cavefast import (
+    EllipsisType,
     HintPep612ParamSpecType,
     HintPep612ParamSpecArgType,
     HintPep612ParamSpecKwargType,
-    # HintPep612ParamSpecVarTypes,
 )
 from beartype._check.metadata.metadecor import BeartypeDecorMeta
-from beartype._data.hint.pep.sign.datapepsigncls import HintSign
-from beartype._data.hint.pep.sign.datapepsigns import (
+from beartype._data.typing.datatypingport import (
+    Hint,
+    ListHints,
+)
+from beartype._data.hint.sign.datahintsigncls import HintSign
+from beartype._data.hint.sign.datahintsigns import (
     HintSignParamSpecArgs,
     HintSignParamSpecKwargs,
 )
@@ -51,7 +55,8 @@ def get_hint_pep612_paramspec(
     paramspec_var: Union[
         HintPep612ParamSpecArgType,
         HintPep612ParamSpecKwargType,
-    ]) -> HintPep612ParamSpecType:
+    ]
+) -> HintPep612ParamSpecType:
     '''
     :pep:`612`-compliant **parameter specification** (i.e., low-level C-based
     :obj:`typing.ParamSpec` object) containing the passed **parameter
@@ -83,10 +88,11 @@ def get_hint_pep612_paramspec(
     return paramspec_var.__origin__  # type: ignore[union-attr]
 
 # ....................{ FACTORIES                          }....................
+#FIXME: This should probably be memoized by @callable_cached. Probably. *sigh*
 def make_hint_pep612_concatenate_list_or_none(
-    hints_child_first: list,
-    hint_child_last: object,
-) -> object:
+    hints_child_first: ListHints,
+    hint_child_last: Union[Hint, EllipsisType],  # type: ignore[valid-type]
+) -> Hint:
     '''
     :pep:`612`-compliant **parameter concatenation** (i.e., high-level
     pure-Python object created and returned by subscripting the standard
@@ -98,10 +104,10 @@ def make_hint_pep612_concatenate_list_or_none(
 
     Parameters
     ----------
-    hints_child_first : list
+    hints_child_first : ListHints
         List of all leading child type hints to subscript the returned
         ``typing.Concatenate[...]`` type hint with.
-    hint_child_last : object
+    hint_child_last : Union[Hint, EllipsisType]
         Trailing child type hint to subscript the returned
         ``typing.Concatenate[...]`` type hint with. Note that both :pep:`612`
         *and* the runtime implementation of the :func:`typing.Concatenate` type
@@ -116,7 +122,7 @@ def make_hint_pep612_concatenate_list_or_none(
 
     Returns
     -------
-    object
+    Hint
         Either:
 
         * If :func:`typing.Concatenate` is importable, the
@@ -127,8 +133,10 @@ def make_hint_pep612_concatenate_list_or_none(
     Raises
     ------
     TypeError
-        If ``hint_child_last`` is neither a parameter specification *nor* an
-        ellipsis.
+        If ``hint_child_last`` is neither:
+
+        * A parameter specification.
+        * An ellipsis.
     '''
     assert isinstance(hints_child_first, list), (
         f'{repr(hints_child_first)} not list.')
@@ -151,6 +159,7 @@ def make_hint_pep612_concatenate_list_or_none(
         # Note that the Concatenate.__getitem__() implementation *REQUIRES* that
         # the passed parameter be a tuple. Sanity is out the window, folks.
         hints_child = tuple(hints_child_first) + (hint_child_last,)
+        # print(f'hints_child_first: {hints_child_first}; hint_child_last: {hint_child_last}')
 
         # "Concatenate[...]" hint dynamically subscripted by this tuple.
         hint = Concatenate.__getitem__(hints_child)  # type: ignore[misc]
@@ -158,7 +167,7 @@ def make_hint_pep612_concatenate_list_or_none(
     # returning "None".
 
     # Return this "Concatenate[...]" hint.
-    return hint
+    return hint  # pyright: ignore
 
 # ....................{ REDUCERS                           }....................
 def reduce_hint_pep612_args(hint: object, **kwargs,) -> object:
@@ -298,7 +307,7 @@ parameter.
 # ....................{ PRIVATE ~ reducers                 }....................
 def _reduce_hint_pep612_args_or_kwargs(
     # General-purpose parameters passed by the higher-level
-    # beartype._check.convert._reduce.redhint.reduce_hint() reducer to this
+    # beartype._check.convert._reduce.redmain.reduce_hint() reducer to this
     # lower-level reducer.
     hint: object,
     decor_meta: Optional[BeartypeDecorMeta],
@@ -318,7 +327,7 @@ def _reduce_hint_pep612_args_or_kwargs(
     other_pith_name_label: str,
 
     # Ignorable general-purpose parameters passed by the higher-level
-    # beartype._check.convert._reduce.redhint.reduce_hint() reducer *NOT* required
+    # beartype._check.convert._reduce.redmain.reduce_hint() reducer *NOT* required
     # by this lower-level reducer.
     **kwargs
 ) -> object:
@@ -528,7 +537,7 @@ def _reduce_hint_pep612_args_or_kwargs(
 
     # Type hint subscripting the other variadic parameter if any *OR* the
     # sentinel placeholder otherwise.
-    other_arg_hint = decor_meta.func_arg_name_to_hint_get(
+    other_arg_hint = decor_meta.func_annotations_get(
         other_arg_name, SENTINEL)
 
     # If the other variadic parameter is unannotated, raise an exception.
@@ -547,7 +556,7 @@ def _reduce_hint_pep612_args_or_kwargs(
     # Else, the other variadic parameter is annotated by a hint.
 
     # Sign uniquely identifying the hint annotating other variadic parameter.
-    other_arg_hint_sign = get_hint_pep_sign_or_none(other_arg_hint)
+    other_arg_hint_sign = get_hint_pep_sign_or_none(other_arg_hint)  # pyright: ignore
 
     # If the hint annotating the other variadic parameter is *NOT* the other
     # variadic positional or keyword parameter hint required by PEP
