@@ -13,8 +13,6 @@ child submodules of the test subpackage containing this :mod:`pytest` plugin).
 # ....................{ IMPORTS                            }....................
 # Import all subpackage-specific fixtures implicitly required by tests defined
 # by submodules of this subpackage.
-from beartype_test.a00_unit.a40_api.door._fixture._doorfix_infer_hint import (
-    door_cases_infer_hint)
 from beartype_test.a00_unit.a40_api.door._fixture._doorfix_is_subhint import (
     door_cases_is_subhint)
 from beartype_test.a00_unit.a40_api.door._fixture._doorfix_typehint import (
