@@ -27,7 +27,6 @@ This submodule unit tests :pep:`563` support implemented in the
 #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
 from beartype_test._util.mark.pytskip import (
-    # skip,
     skip_if_pypy,
     skip_if_python_version_less_than,
     skip_if_python_version_greater_than_or_equal_to,
@@ -138,29 +137,38 @@ def test_pep563_module() -> None:
     # ....................{ IMPORTS                        }....................
     # Defer test-specific imports.
     from beartype import beartype
-    from beartype.roar import BeartypeDecorHintPep604Exception
-    from beartype._util.py.utilpyversion import IS_PYTHON_AT_LEAST_3_10
+    from beartype._util.hint.pep.proposal.pep649 import (
+        get_pep649_hintable_annotations,
+        set_pep649_hintable_annotations,
+    )
     from beartype_test.a00_unit.data.pep.pep563.data_pep563_poem import (
         get_minecraft_end_txt,
         get_minecraft_end_txt_pep604,
         get_minecraft_end_txt_stanza,
     )
-    from pytest import raises
 
     # ....................{ LOCALS                         }....................
     # Dictionary of these callables' annotations, localized to enable debugging
     # in the likely event of unit test failure. *sigh*
-    GET_MINECRAFT_END_TXT_ANNOTATIONS = get_minecraft_end_txt.__annotations__
-    GET_MINECRAFT_END_TXT_STANZA_ANNOTATIONS = (
-        get_minecraft_end_txt_stanza.__annotations__)
+    get_minecraft_end_txt_annotations = get_pep649_hintable_annotations(
+        get_minecraft_end_txt)
+    get_minecraft_end_txt_stanza_annotations = get_pep649_hintable_annotations(
+        get_minecraft_end_txt_stanza)
+
+    # from annotationlib import Format
+    # hintable = get_minecraft_end_txt_stanza
+    # print(f'{hintable}.__annotate__: {hintable.__annotate__}')
+    # print(f'{hintable}.__annotations__: {hintable.__annotations__}')
+    # print(f'{hintable}.__annotate__(3): {hintable.__annotate__(Format.FORWARDREF)}')
+    # hintable_annotations_cached = get_pep649_hintable_annotations(hintable)
+    # print(f'{hintable}.__annotate__(3) [cached]: {hintable_annotations_cached}')
 
     # ....................{ ASSERTS                        }....................
     # Assert that all annotations of a callable *NOT* decorated by @beartype
     # are postponed under PEP 563 as expected.
     assert all(
         isinstance(param_hint, str)
-        for arg_name, param_hint in (
-            GET_MINECRAFT_END_TXT_ANNOTATIONS.items())
+        for arg_name, param_hint in get_minecraft_end_txt_annotations.items()
     )
 
     # Assert that *NO* annotations of a @beartype-decorated callable are
@@ -168,7 +176,7 @@ def test_pep563_module() -> None:
     assert all(
         not isinstance(param_hint, str)
         for arg_name, param_hint in (
-            GET_MINECRAFT_END_TXT_STANZA_ANNOTATIONS.items())
+            get_minecraft_end_txt_stanza_annotations.items())
     )
 
     # Assert that a @beartype-decorated callable works under PEP 563.
@@ -180,34 +188,27 @@ def test_pep563_module() -> None:
     # case that needlessly complicates code life.
     #
     # Manually resolve all postponed annotations on a callable.
-    get_minecraft_end_txt.__annotations__ = {
-        arg_name: eval(param_hint, get_minecraft_end_txt.__globals__)
-        for arg_name, param_hint in (
-            get_minecraft_end_txt.__annotations__.items())
-    }
+    set_pep649_hintable_annotations(
+        hintable=get_minecraft_end_txt,
+        annotations={
+            arg_name: eval(param_hint, get_minecraft_end_txt.__globals__)
+            for arg_name, param_hint in (
+                get_pep649_hintable_annotations(get_minecraft_end_txt).items())
+        },
+    )
 
+    # ....................{ ASSERTS ~ decorator            }....................
     # Manually decorate this callable with @beartype.
     get_minecraft_end_txt_typed = beartype(get_minecraft_end_txt)
 
-    # Assert that this callable works under PEP 563.
-    assert isinstance(get_minecraft_end_txt_typed(player_name='Notch'), str)
+    # Manually decorate a PEP 604-compliant callable with @beartype.
+    get_minecraft_end_txt_pep604_typed = beartype(get_minecraft_end_txt_pep604)
 
-    # ....................{ ASSERTS ~ pep 604              }....................
-    # If the active Python interpreter targets Python >= 3.10 and thus supports
-    # PEP 604...
-    if IS_PYTHON_AT_LEAST_3_10:
-        # Manually decorate a PEP 604-compliant callable with @beartype.
-        get_minecraft_end_txt_typed = beartype(get_minecraft_end_txt_pep604)
-
-        # Assert that this callable works under PEP 563.
-        assert isinstance(get_minecraft_end_txt_typed(player_name='Notch'), str)
-    # Else, the active Python interpreter targets Python < 3.10 and thus fails
-    # to support PEP 604. In this case..
-    else:
-        # Assert that attempting to manually decorate a PEP 604-compliant
-        # callable with @beartype raises the expected exception.
-        with raises(BeartypeDecorHintPep604Exception):
-            beartype(get_minecraft_end_txt_pep604)
+    # Assert that these callables behave as expected under PEP 563.
+    assert isinstance(
+        get_minecraft_end_txt_typed(player_name='Notch'), str)
+    assert isinstance(
+        get_minecraft_end_txt_pep604_typed(player_name='Notch'), str)
 
 
 def test_pep563_class() -> None:
